@@ -73,7 +73,7 @@ int main(int argc, char* argv[])
 
     // explicitly disable input methods as it makes it impossible to unlock, see BUG 306932
     // but explicitly set on screen keyboard such as maliit is allowed
-    if (qgetenv("QT_IM_MODULE") != QByteArrayLiteral("maliit")) {
+    if (qEnvironmentVariableIsSet("QT_IM_MODULE") && qgetenv("QT_IM_MODULE") != QByteArrayLiteral("maliit")) {
         qputenv("QT_IM_MODULE", QByteArrayLiteral("compose"));
     }
     ScreenLocker::UnlockApp app(argc, argv);
@@ -110,6 +110,9 @@ int main(int argc, char* argv[])
                                        QStringLiteral("0"));
     QCommandLineOption nolockOption(QStringLiteral("nolock"),
                                     i18n("Don't show any lock user interface."));
+    QCommandLineOption switchUserOption(QStringLiteral("switchuser"),
+                                    i18n("Default to the switch user UI."));
+
     QCommandLineOption waylandFdOption(QStringLiteral("ksldfd"),
                                        i18n("File descriptor for connecting to ksld."),
                                        QStringLiteral("fd"));
@@ -119,6 +122,7 @@ int main(int argc, char* argv[])
     parser.addOption(immediateLockOption);
     parser.addOption(graceTimeOption);
     parser.addOption(nolockOption);
+    parser.addOption(switchUserOption);
     parser.addOption(waylandFdOption);
     parser.process(app);
 
@@ -151,6 +155,10 @@ int main(int argc, char* argv[])
         app.setGraceTime(graceTime);
     }
 
+    if (parser.isSet(switchUserOption)) {
+        app.setDefaultToSwitchUser(true);
+    }
+
     if (parser.isSet(waylandFdOption)) {
         ok = false;
         const int fd = parser.value(waylandFdOption).toInt(&ok);
