@@ -23,6 +23,14 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #include "abstractlocker.h"
 
+namespace KWayland
+{
+namespace Server
+{
+class Display;
+}
+}
+
 namespace ScreenLocker
 {
 
@@ -31,8 +39,8 @@ class WaylandLocker : public AbstractLocker
     Q_OBJECT
 
 public:
-    WaylandLocker();
-    ~WaylandLocker();
+    WaylandLocker(KWayland::Server::Display *display, QObject *parent);
+    virtual ~WaylandLocker();
 
     void showLockWindow() override;
     void hideLockWindow() override;
